@@ -54,3 +54,13 @@ def weather():
             weather_spider(url, headers)
         except:
             print('未查到%s城市，请重新输入：' % cityName)
+
+
+import socket
+
+
+# 通过url，获取ip地址
+def url2ip(url):
+    socket_list = socket.getaddrinfo(url, None, 0, socket.SOCK_STREAM)
+    ip_info = socket_list[0][4][0]
+    print('【{}】 这个网址对应的IP地址是：{}'.format(url, ip_info))
